<?php
declare(strict_types=1);

namespace Tiara\Orm;

use Doctrine\Common\Annotations\Reader;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
use Doctrine\Persistence\Mapping\Driver\MappingDriver;

/**
 * Class ConfigProvider
 *
 * @package Tiara\Orm
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-orm
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            'orm' => [
                'connection' => [],
                'entity_paths' => [],
                'proxy_dir' => sys_get_temp_dir(),
            ],

            'dependencies' => [
                'factories' => [
                    'orm.cache' => Container\CacheFactory::class,
                    'orm.connection' => Container\ConnectionFactory::class,
                    AnnotationDriver::class => Container\AnnotationDriverFactory::class,
                    EntityManagerInterface::class => Container\EntityManagerFactory::class,
                    MappingDriver::class => Container\MappingDriverFactory::class,
                    Reader::class => Container\AnnotationReaderFactory::class,
                ],
                'shared' => [
                    AnnotationDriver::class => false,
                ],
            ],
        ];
    }
}
