<?php
declare(strict_types=1);

namespace Tiara\Orm\Container;

use Doctrine\ORM\Configuration;
use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\ORMException;
use Doctrine\Persistence\Mapping\Driver\MappingDriver;
use Psr\Container\ContainerInterface;

/**
 * Class EntityManagerFactory
 *
 * @package Tiara\Orm\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-orm
 */
final class EntityManagerFactory
{
    /**
     * @param ContainerInterface $container
     * @return EntityManagerInterface
     * @throws ORMException
     */
    public function __invoke(ContainerInterface $container): EntityManagerInterface
    {
        $config = $container->get('config')['orm'] ?? [];

        $connection = $container->get('orm.connection');
        $configuration = new Configuration();

        $configuration->setMetadataDriverImpl(
            $container->get(MappingDriver::class)
        );

        $configuration->setProxyDir($config['proxy_dir'] ?? '');
        $configuration->setProxyNamespace('Tiara\\Orm\\');

        return EntityManager::create(
            $connection,
            $configuration
        );
    }
}
