<?php
declare(strict_types=1);

namespace Tiara\Orm\Container;

use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
use Doctrine\Persistence\Mapping\Driver\MappingDriver;
use Doctrine\Persistence\Mapping\Driver\MappingDriverChain;
use Psr\Container\ContainerInterface;

/**
 * Class MappingDriverFactory
 *
 * @package Tiara\Orm\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-orm
 */
final class MappingDriverFactory
{
    public function __invoke(ContainerInterface $container): MappingDriver
    {
        $config = $container->get('config')['orm'] ?? [];
        $chain = new MappingDriverChain();

        foreach ($config['entity_paths'] ?? [] as $namespace => $path) {
            /** @var AnnotationDriver $driver */
            $driver = $container->get(AnnotationDriver::class);
            $driver->addPaths((array) $path);
            $chain->addDriver($driver, $namespace);
        }

        return $chain;
    }
}
