<?php
declare(strict_types=1);

namespace TiaraTest\Orm;

use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ServiceManager\ServiceManager;
use PHPUnit\Framework\TestCase;
use Psr\Container\ContainerInterface;
use Tiara\Orm\ConfigProvider;

/**
 * Class AbstractTestCase
 *
 * @package TiaraTest\Orm
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-orm
 */
abstract class AbstractTestCase extends TestCase
{
    protected function getContainer(array $config = []): ContainerInterface
    {
        $config = (new ConfigAggregator([
            ConfigProvider::class,
            new ArrayProvider([
                'orm' => [
                    'connection' => [
                        'driver' => 'pdo_sqlite',
                        'memory' => true,
                    ],
                    'entity_paths' => [
                        __NAMESPACE__ . '\\Entity' => __DIR__ . '/Entity',
                    ],
                ],
            ]),
            new ArrayProvider($config),
        ]))->getMergedConfig();

        $config['dependencies']['services']['config'] = $config;

        return new ServiceManager($config['dependencies']);
    }
}
